[![Build Status](https://travis-ci.org/Roguelazer/send_nsca.png?branch=master)](https://travis-ci.org/Roguelazer/send_nsca)

Overview
----
NSCA is the remote passive acceptance daemon used with many Nagios installs. It
ships with a (C-language) executable called `send_nsca` for submitting checks.
This is a mostly-clean re-implementation of `send_nsca` in pure-python. It
supports 10 of the 26 crypto functions used by upstream NSCA, sending to
multiple hosts with one invocation, and timeouts.

Why send_nsca3?
----
Python3 compatible version of send_nsca, packaged for pypi installation. Just a
personal convenience thing, as as none of libraries for sending nsca checks 
support python3, and the projects don't seem active.

Credits/Copyright/License
---
- This software was written by James Brown <jbrown@uber.com>.
- This software is licensed under the LGPL v2.1

Testing
-----
The unit/integration tests for this package are located in the `tests/`
directory.  Unit tests only require the unittest package (or python 2.7+)
and the mock library; integration tests also require the `nsca` binary. To
run them, simply make sure that your `$PYTHONPATH` is set up correctly and
run `nosetests -v tests`.

Installing
-----
This software uses setuptools/distutils; you can install it with `sudo python setup.py install`,
and it's easy to write packaging for your favorite OS.

Contributing
----------
It's Github; fork away!
